// Layout
import "../components/dashboards/layout/Panel";
import "../components/dashboards/layout/Container";

// General
import "../components/dashboards/Error";
import "../components/dashboards/Table";
import "../components/dashboards/Text";

// Charts
import "../components/dashboards/charts/AreaChart";
import "../components/dashboards/charts/BarChart";
import "../components/dashboards/charts/ColumnChart";
import "../components/dashboards/charts/DonutChart";
import "../components/dashboards/charts/LineChart";
import "../components/dashboards/charts/PieChart";
import "../components/dashboards/charts/Chart";

// Flows
import "../components/dashboards/flows/Sankey";
import "../components/dashboards/flows/Flow";

// Graphs
import "../components/dashboards/graphs/ForceDirectedGraph";
import "../components/dashboards/graphs/Graph";

// Hierarchies
import "../components/dashboards/hierarchies/Tree";
import "../components/dashboards/hierarchies/Hierarchy";

// Inputs
import "../components/dashboards/inputs/MultiComboInput";
import "../components/dashboards/inputs/MultiSelectInput";
import "../components/dashboards/inputs/SingleComboInput";
import "../components/dashboards/inputs/SingleSelectInput";
import "../components/dashboards/inputs/TextInput";
import "../components/dashboards/inputs/Input";

// Check
import "../components/dashboards/check/CheckGrouping";
import "../components/dashboards/check/Benchmark";
import "../components/dashboards/layout/Dashboard";
import "../components/dashboards/Image";
import "../components/dashboards/Card";
